# Python ETB Library

This is a python library to write tests for the Embedded Testbench.

## User documentation

### How to install library
- `pip install /path/to/wheelfile.whl`
- `python3 -m pip install /path/to/wheelfile.whl`

### How to use library in python
- Import
    - `from py_etb.etb import ETB_handler`
    - `from py_etb.etb import Pipe`
- Objects
    - `ETB_handler`: Singleton
        - `handle = ETB_handler(sys.argv[1])`
        - `sys.argv[1]`: is list of the opened pipes, created by the ETB application
    - `Pipe`: Communication pipes
        - Actual Result
            - e.g. current process in %
        - Detail View
            - e.g. graphics or tables
- Send data through communication channel
    - `ETB_handler().send_actual_result(`*text_as_string*`, `optional: *line_endings*=True`)`
    - `ETB_handler().send_detail_view(`*data_as_binary*`, `optional: *line_endings*=True`)`
    - `line_endings` default = False
    - `line_endings` True = `\n`

## Maintainer documentation

### [How to build library](https://medium.com/analytics-vidhya/how-to-create-a-python-library-7d5aea80cc3f)

### Required python packages
- To install via `pip install ...`
    - `wheel`
    - `setuptools`
    - `twine`

### Build library
- `python setup.py bdist_wheel`
    - Note: You have to be in lib directory
        - `cd /path/to/etb_python_lib`

### Result
This will create a wheel file (`.whl`) in `dist` directory

### Description
- `ETB_handler` is a multi-pipeline handler
    - When instantiate, `ETB_handler` sets up all necessary communcation pipes to handle with ETB
    - `ETB_handler` is designed as a Singleton, to prevent impossible multiple opening of the same communication channels to `ETB`
- `Pipe` is an enumeration to set the wanted communication channel